Struct concread::arcache::CacheStats [−][src]
pub struct CacheStats {
pub reader_hits: usize,
pub reader_tlocal_hits: usize,
pub reader_includes: usize,
pub write_hits: usize,
pub write_inc_or_mod: usize,
pub shared_max: usize,
pub freq: usize,
pub recent: usize,
pub freq_evicts: usize,
pub recent_evicts: usize,
pub p_weight: usize,
pub all_seen_keys: usize,
}Expand description
Statistics related to the Arc
Fields
reader_hits: usizeThe number of hits during all read operations on the primary cache.
reader_tlocal_hits: usizeThe number of hits during all read operations on the thread local caches.
reader_includes: usizeThe number of inclusions through read operations.
write_hits: usizeThe number of hits during all write operations.
write_inc_or_mod: usizeThe number of inclusions or changes through write operations.
The maximum number of items in the shared cache.
freq: usizeThe number of items in the frequent set
recent: usizeThe number of items in the recent set
freq_evicts: usizeThe number of items evicted from the frequent set
recent_evicts: usizeThe number of items evicted from the recent set
p_weight: usizeThe current cache weight between recent and frequent.
all_seen_keys: usizeThe number of keys seen through the cache’s lifetime.